# EmUtils - Miscellanous Python Utilities

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/emutils.svg)](https://pypi.python.org/pypi/emutils/)
[![GitHub license](https://img.shields.io/github/license/emanuele-albini/emutils)](https://github.com/emanuele-albini/emutils/blob/master/LICENSE)
[![PyPI](https://badge.fury.io/py/emutils.svg)](https://pypi.python.org/pypi/emutils/)
[![Maintaner](https://img.shields.io/badge/maintainer-Emanuele-lightgrey)](https://www.emanuelealbini.com)
[![Tests](https://github.com/emanuele-albini/emutils/actions/workflows/tests.yml/badge.svg)](https://github.com/emanuele-albini/emutils/actions/workflows/tests.yml)
<!-- [![Release](https://github.com/emanuele-albini/emutils/actions/workflows/release.yml/badge.svg)](https://github.com/emanuele-albini/emutils/actions/workflows/release.yml) -->

This package contains various Python utilities.

**Package under active development. Please use specific releases version from PyPi or conda for stable versions.**

## Installation

Using PIP:

```bash
pip install emutils
```

#### For developers

To use the package in editable mode use instead the following.

```bash
git clone https://github.com/emanuele-albini/emutils.git
pip install --editable emutils
```


## Documentation

See [here](https://emanuele-albini.github.io/emutils) for the complete documentation of the modules.
